# -*- coding: utf-8 -*-
# author: 华测-长风老师
# file name：unzip.py

import zipfile
import os
import sys


def get_home_path():
    env_vars = os.environ
    for var in env_vars:
        if var == "USERPROFILE" if sys.platform == "win32" else "HOME":
            return env_vars[var]


def unzip(source_path, target_path):
    with zipfile.ZipFile(source_path, 'r') as zip_ref:
        zip_ref.extractall(target_path)
    for root, dirs, files in os.walk(target_path):
        for file in files:
            os.chmod(os.path.join(root, file), 0o755)


if __name__ == '__main__':
    get_home_path()



# -*- coding: utf-8 -*-
# author: 华测-长风老师
# file name：mac_env.py

import subprocess


def add_system_env_path(path_):
    cmd = f"echo export 'PATH={path_}:$PATH.' >> ~/.bash_profile"
    subprocess.call(cmd, shell=True)


def add_system_env(env_name, env_value):
    cmd = f"echo export '{env_name}={env_value}' >> ~/.bash_profile"
    subprocess.call(cmd, shell=True)



# -*- coding: utf-8 -*-
# author: 华测-长风老师
# file name：windows_env.py


import winreg


def add_system_env_path(path_):
    try:

        key = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, r'SYSTEM\CurrentControlSet\Control\Session Manager\Environment',
                             0, winreg.KEY_ALL_ACCESS)
        value, type_ = winreg.QueryValueEx(key, "Path")
        if path_ not in value:
            value = value.rstrip(";")  # 去除末尾的分号
            value += ";" + path_
            winreg.SetValueEx(key, "Path", 0, type_, value)
            print(f"Successfully added {path_} to system environment variables.")
        else:
            print(f"{path_} already exists in system environment variables.")
    except WindowsError:
        print("Error occurred while trying to add path to system environment variables.")


def add_system_env(env_name, env_value):
    try:

        key = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, r'SYSTEM\CurrentControlSet\Control\Session Manager\Environment',
                             0, winreg.KEY_READ)
        try:
            value, regtype = winreg.QueryValueEx(key, env_name)
        except FileNotFoundError:
            value = None
        winreg.CloseKey(key)

        if value == env_value:
            pass
        else:
            key = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE,
                                 r'SYSTEM\CurrentControlSet\Control\Session Manager\Environment', 0,
                                 winreg.KEY_ALL_ACCESS)
            winreg.SetValueEx(key, env_name, 0, winreg.REG_EXPAND_SZ, env_value)
            winreg.CloseKey(key)

    except WindowsError as e:
        print(e)
        print("Error occurred while trying to add path to system environment variables.")

# if __name__ == '__main__':
# add_system_env("JAVA_HOME", r"D:\\JAVA_12_HOME")
# add_system_env_path(r"%JAVA_HOME%\bin")



# -*- coding: utf-8 -*-
# author: 华测-长风老师
# file name：adb_env.py

from hctest_install_help.package.unzip import *

ANDROID_HOME_NAME = "ANDROID_HOME"
JAVA_HOME_NAME = "JAVA_HOME"
adb_path = None
aapt_path = None
adb_zip_file = input("请输入你adb源文件(zip文件)绝对路径:\n")
aapt_zip_file = input("请输入你的appt源文件(zip文件)绝对路径:\n")
save_path = input("请输入你想保存的位置(文件夹的绝对路径):\n")

if not save_path:
    home = get_home_path()
    target_path = os.path.abspath(home + r"\SDK" if sys.platform == "win32" else home + r"/.SDK")
    unzip(adb_zip_file, target_path)
    unzip(aapt_zip_file, target_path)

else:
    target_path = os.path.abspath(save_path)
    unzip(adb_zip_file, target_path)
    unzip(aapt_zip_file, target_path)

for dir_path, dir_names, filenames in os.walk(target_path):
    for filename in filenames:
        if filename.endswith("adb.exe" if sys.platform == "win32" else "adb"):
            adb_path = os.path.join(dir_path)

for dir_path, dir_names, filenames in os.walk(target_path):
    for filename in filenames:
        if filename.endswith("aapt.exe" if sys.platform == "win32" else "aapt"):
            aapt_path = os.path.join(dir_path)

if sys.platform == "win32":
    from hctest_install_help.package.windows_env import *

    add_system_env_path(r"%ANDROID_HOME%{};%ANDROID_HOME%{}".format(aapt_path.replace(target_path, ''),
                                                                    adb_path.replace(target_path, '')))
    add_system_env(ANDROID_HOME_NAME, target_path)
    # 将文件夹属性设置为隐藏
    attributes = os.stat(target_path).st_file_attributes
    FILE_ATTRIBUTE_HIDDEN = 0x02
    os.stat(target_path).st_file_attributes = attributes | FILE_ATTRIBUTE_HIDDEN

else:
    from hctest_install_help.package.mac_env import *

    add_system_env_path(r"$ANDROID_HOME{}:$ANDROID_HOME{}".format(aapt_path.replace(target_path, ''),
                                                                  adb_path.replace(target_path, '')))
    add_system_env(ANDROID_HOME_NAME, target_path)



# -*- coding: utf-8 -*-
# author: 华测-长风老师
# file name：run.py

import ctypes
import sys


def run_cmd_as_admin(cmd):
    if not ctypes.windll.shell32.IsUserAnAdmin():
        ctypes.windll.shell32.ShellExecuteW(None, "runas", "cmd.exe", "/k {}".format(cmd), None, 1)
    else:
        import os
        os.system(cmd)


def start_install_help():
    if sys.platform == "win32":
        env_file = str(__file__).replace(f"run.py", "adb_env.py")
        run_cmd_as_admin(f"{sys.executable} {env_file}")

    else:
        import os
        env_file = str(__file__).replace(f"run.py", "adb_env.py")
        os.system(f'{sys.executable} {env_file}')



# -*- coding: utf-8 -*-
# author: 华测-长风老师
# file name：setup.py
from setuptools import setup, find_packages

setup(
    name="hctest_install_help",
    version="0.7",
    description="辅助帮你下载安装文件",
    author="cf",
    author_email="dingjun_baby@yeah.net",
    url="https://github.com/pypa/sampleproject",
    packages=find_packages(),
    # install_requires=[
    #     'requests',
    # ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
